@@ -25,6 +25,7 @@ parameters or headers don't cause any UnicodeEncodeError problems.
 Joe Gregario's httplib2 library is required. It can be easy_installed, or downloaded
 
 CHANGESET:
+  * 2007-03-06 - Anders - merged Christopher Hesse's bugfix and self-contained test suite
   * 2006-12-01 - Anders - switched to httplib2. Improved handling of parameters and made it
                           stricter about unicode in headers (only ASCII is allowed). Added
                           resp option. More docstrings.
@@ -42,7 +43,7 @@ n                          and we now use post_multipart for everything since it
 
 import urllib2,urllib, mimetypes, types, thread, httplib2
 
-__version__ = "0.9.5"
+__version__ = "0.9.6"
 
 def post_multipart(host, selector, method,fields, files, headers={},return_resp=False):
     """
@@ -233,7 +234,7 @@ def _rest_invoke(url,method=u"GET",params={},files={},accept=[],headers={},resp=
 def non_multipart(params,host,method,path,headers,return_resp):
     params = urllib.urlencode(params)
     if method == "GET":
-        headers['Content-Length'] = 0
+        headers['Content-Length'] = '0'
         if params:
             # put the params into the url instead of the body
             if "?" not in path:
